@@ -152,7 +152,7 @@ on_configure_button_clicked (GtkButton *button, gpointer data)
 							 GTK_DIALOG_DESTROY_WITH_PARENT,
 							 GTK_MESSAGE_ERROR,
 							 GTK_BUTTONS_CLOSE,
-							 error->message);
+							 "%s", error->message);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
 		}
@@ -233,7 +233,7 @@ on_finger_activate (GtkWidget * widget, gpointer data)
 		text = g_strdup (gtk_entry_get_text (entry_host));
 		g_strstrip (text);
 
-		if (g_strcasecmp (text, "") != 0)
+		if (strlen(text) > 0)
 			gn_combo_history_add (finger->history, text);
 		
 		g_free (text);
@@ -243,7 +243,7 @@ on_finger_activate (GtkWidget * widget, gpointer data)
 		text = g_strdup (gtk_entry_get_text (entry_host));
 		g_strstrip (text);
 		
-		if (g_strcasecmp (text, "") != 0)
+		if (strlen(text) > 0)
 			gn_combo_history_add (finger->history_user, text);
 		
 		g_free (text);
@@ -306,33 +306,44 @@ on_beep_activate (GtkWidget *menu_item, gpointer data)
 }
 
 void
-on_about_activate (GtkWidget *menu_item, gpointer data)
+on_about_activate (gpointer window, GtkWidget *menu_item)
 {
 	const gchar *authors[] = { 
-		"Germán Poo Caamaño <gpoo@ubiobio.cl>", 
+		"Germán Poo Caamaño <gpoo@gnome.org>", 
 		"William Jon McCann <mccann@jhu.edu>",
 		"Carlos Garcia Campos <carlosgc@gnome.org>",
-		"Rodrigo Moya <rodrigo@gnome-db.org>", NULL
+		"Rodrigo Moya <rodrigo@gnome-db.org>", 
+		NULL
+	};
+	const gchar *artists[] = { 
+		"Hylke Bons <h.bons@student.rug.nl>", 
+		NULL
 	};
 	const gchar *documentors[] = { NULL };
 	const gchar *translator_credits = _("translator-credits");
 	gchar	     copyright[1024];
 	GtkWindow   *parent;
 
-	parent = (GtkWindow *) data;
+	parent = (GtkWindow *) window;
 
-	g_sprintf (copyright, "Copyright \xc2\xa9 2003-2004 %s", "Germán Poo Caamaño");
+	/* Translators: %s is the name of the copyright holder */
+	g_sprintf (copyright, _("Copyright \xc2\xa9 2003-2008 %s"), "Germán Poo Caamaño");
 	
 	gtk_show_about_dialog (parent,
 			       /* Dear translator: This is the name of the application */
+			       "program-name", _("Network Tools"),
 			       "name", _("Network Tools"),
-			       "logo-icon-name", "gnome-nettool",
 			       "authors", authors,
-			       "documenters", documentors,
-			       "version", VERSION,
-			       "copyright", copyright,
 			       "comments", _("Graphical user interface for common network utilities"),
-			       "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			       "copyright", copyright,
+			       "artists", artists,
+			       "documenters", documentors,
+			       "license", "GPL 2+",
+			       "logo-icon-name", "gnome-nettool",
+			       "translator-credits", translator_credits,
+			       "version", PACKAGE_VERSION,
+			       "website", PACKAGE_URL,
+			       "wrap-license", TRUE,
 			       NULL);
 }
 
@@ -374,13 +385,11 @@ get_netinfo_for_page (GtkNotebook * notebook, gint page_num)
 }
 
 void
-on_copy_activate (GtkWidget *menu_item, gpointer data)
+on_copy_activate (gpointer notebook, GtkWidget *menu_item)
 {
 	gint page;
 	Netinfo *netinfo;
 
-	GtkNotebook *notebook = (GtkNotebook *) data;
-
 	g_return_if_fail (GTK_IS_NOTEBOOK (notebook));
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
@@ -395,12 +404,10 @@ on_copy_activate (GtkWidget *menu_item, gpointer data)
 }
 
 void
-on_clear_history_activate (GtkWidget *menu_item, gpointer data)
+on_clear_history_activate (gpointer notebook, GtkWidget *menu_item)
 {
 	Netinfo *netinfo;
 
-	GtkNotebook *notebook = (GtkNotebook *) data;
-
 	g_return_if_fail (GTK_IS_NOTEBOOK (notebook));
 
 	/* Pages all share a history id for host entry except whois */
@@ -417,7 +424,7 @@ on_clear_history_activate (GtkWidget *menu_item, gpointer data)
 
 void
 on_page_switch (GtkNotebook     * notebook,
-		GtkNotebookPage * page,
+		gpointer          page,
 		guint             page_num,
 		gpointer          data)
 {
@@ -438,6 +445,8 @@ on_page_switch (GtkNotebook     * notebook,
 	} else {
 		netinfo_progress_indicator_stop (netinfo);
 		gtk_statusbar_pop (GTK_STATUSBAR (netinfo->status_bar), 0);
+		gtk_statusbar_push (GTK_STATUSBAR (netinfo->status_bar),
+					    0, _("Idle"));
 	}
 
 	/* Dear Translator: This is the Window Title. 'Network Tools' is the
@@ -447,3 +456,33 @@ on_page_switch (GtkNotebook     * notebook,
 	gtk_window_set_title (GTK_WINDOW (netinfo->main_window), title);
 	g_free (title);
 }
+
+void
+on_help_activate (gpointer window, GtkWidget *menu_item)
+{
+	GdkScreen *screen;
+	GError *error = NULL;
+
+	g_return_if_fail (GTK_IS_WINDOW (window));
+
+	screen = gtk_widget_get_screen (window);
+	gtk_show_uri (screen, "ghelp:gnome-nettool",
+			      gtk_get_current_event_time (), &error);
+
+	if (error) {
+		GtkWidget *dialog;
+		dialog = gtk_message_dialog_new (
+			      GTK_WINDOW (window), 
+		              GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		              GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
+			      "%s", _("Unable to open help file"));
+		gtk_message_dialog_format_secondary_text (
+			      GTK_MESSAGE_DIALOG (dialog),
+			      "%s", error->message);
+		g_signal_connect (dialog, "response", 
+				  G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_window_present (GTK_WINDOW (dialog));
+
+		g_error_free (error);
+	}
+}
